@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 import datetime
 from random import randint
@@ -10,11 +10,8 @@ def run():
     for day in range(365*5):
         dt=basedate+datetime.timedelta(day)
         dtiso=dt.isoformat()
-        print "%s:00:%s:%.2f:1:Note" % (dtiso,prods[0],20.0)
+        print("%s:00:%s:%.2f:1:Note" % (dtiso,prods[0],20.0))
         for i in range(20):
             pr=prods[randint(10,199)]
-            print "%s:00:%s:%.2f:0:Note" % (dtiso,pr,1.0)
-
-
+            print("%s:00:%s:%.2f:0:Note" % (dtiso,pr,1.0))
 run()
-
